==> nextcloud-25.0.6.tgz: nextcloud/lib/l10n/oc.js <==
OC.L10N.register(
    "lib",
    {
    "The page could not be found on the server." : "Se podiá pas trobar la pagina sul servidor.",
    "Other activities" : "Autras activitats",
    "Authentication" : "Autentificacion",
    "Unknown filetype" : "filetype desconegut",
    "Invalid image" : "Imatge invalid",
    "Files" : "Fichièrs",
    "View profile" : "Veire perfil",
    "today" : "uèi",
    "yesterday" : "ièr",
    "_in %n day_::_in %n days_" : ["d’aquí %n jorn","d’aquí %n jorns"],
    "_%n day ago_::_%n days ago_" : ["fa %n jorn","fa %n jorns"],
    "last month" : "lo mes passat",
    "_in %n month_::_in %n months_" : ["d’aquí %n mes","d’aquí %n meses"],
    "_%n month ago_::_%n months ago_" : ["fa %n mes","fa %n meses"],
    "last year" : "l’an passat",
    "_in %n year_::_in %n years_" : ["d’aquí %n annada","d’aquí %n annadas"],
    "_%n year ago_::_%n years ago_" : ["fa %n annada","fa %n annadas"],
    "_in %n hour_::_in %n hours_" : ["d’aquí %n ora","d’aquí %n oras"],
    "_%n hour ago_::_%n hours ago_" : ["fa %n ora ","fa %n oras"],
    "_in %n minute_::_in %n minutes_" : ["d’aquí %n minuta","d’aquí %n minutas"],
    "_%n minute ago_::_%n minutes ago_" : ["fa %n minuta","fa %n minutas"],
    "seconds ago" : "fa qualques segondas",
    "Empty file" : "Fichièr void",
    "File already exists" : "Lo fichièr existís ja",
    "Templates" : "Modèls",
    "__language_name__" : "Occitan",
    "Help" : "Ajuda",
    "Apps" : "Aplicacions",
    "Settings" : "Paramètres",
    "Log out" : "Desconnexion",
    "Users" : "Utilizaires",
    "Email" : "Corrièl",
    "Mail %s" : "Mail %s",
    "Phone" : "Telefòn",
    "Call %s" : "Sonar %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Veire %s sus Twitter",
    "Website" : "Site web",
    "Visit %s" : "Visitar %s",
    "Address" : "Adreça",
    "Profile picture" : "Imatge de perfil",
    "About" : "A prepaus",
    "Headline" : "Títol",
    "Organisation" : "Organizacion",
    "Role" : "Ròtle",
    "Additional settings" : "Paramètres addicionals",
    "Set an admin password." : "Definir un senhal admin.",
    "Open »%s«" : "Dobrir « %s »",
    "Sunday" : "dimenge",
    "Monday" : "diluns",
    "Tuesday" : "dimars",
    "Wednesday" : "dimècres",
    "Thursday" : "dijòus",
    "Friday" : "divendres",
    "Saturday" : "dissabte",
    "January" : "Genièr",
    "February" : "Febrièr",
    "March" : "Març",
    "April" : "Abril",
    "May" : "Mai",
    "June" : "Junh",
    "July" : "Julhet",
    "August" : "Agost",
    "September" : "Setembre",
    "October" : "Octòbre",
    "November" : "Novembre",
    "December" : "Decembre",
    "May." : "Mai.",
    "User disabled" : "Utilizaire desactivat",
    "a safe home for all your data" : "un ostal segur per vòstras donadas",
    "Authentication error" : "Error d’autentificacion",
    "Storage is temporarily not available" : "Emmagazinatge temporàriament indisponible",
    "Full name" : "Nom complèt"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-27.1.7p0.tgz: nextcloud/lib/l10n/oc.js <==
OC.L10N.register(
    "lib",
    {
    "The page could not be found on the server." : "Se podiá pas trobar la pagina sul servidor.",
    "Other activities" : "Autras activitats",
    "Authentication" : "Autentificacion",
    "Unknown filetype" : "filetype desconegut",
    "Invalid image" : "Imatge invalid",
    "Files" : "Fichièrs",
    "View profile" : "Veire perfil",
    "today" : "uèi",
    "yesterday" : "ièr",
    "_in %n day_::_in %n days_" : ["d’aquí %n jorn","d’aquí %n jorns"],
    "_%n day ago_::_%n days ago_" : ["fa %n jorn","fa %n jorns"],
    "last month" : "lo mes passat",
    "_in %n month_::_in %n months_" : ["d’aquí %n mes","d’aquí %n meses"],
    "_%n month ago_::_%n months ago_" : ["fa %n mes","fa %n meses"],
    "last year" : "l’an passat",
    "_in %n year_::_in %n years_" : ["d’aquí %n annada","d’aquí %n annadas"],
    "_%n year ago_::_%n years ago_" : ["fa %n annada","fa %n annadas"],
    "_in %n hour_::_in %n hours_" : ["d’aquí %n ora","d’aquí %n oras"],
    "_%n hour ago_::_%n hours ago_" : ["fa %n ora ","fa %n oras"],
    "_in %n minute_::_in %n minutes_" : ["d’aquí %n minuta","d’aquí %n minutas"],
    "_%n minute ago_::_%n minutes ago_" : ["fa %n minuta","fa %n minutas"],
    "seconds ago" : "fa qualques segondas",
    "Empty file" : "Fichièr void",
    "File already exists" : "Lo fichièr existís ja",
    "Templates" : "Modèls",
    "__language_name__" : "Occitan",
    "Help" : "Ajuda",
    "Apps" : "Aplicacions",
    "Settings" : "Paramètres",
    "Log out" : "Desconnexion",
    "Users" : "Utilizaires",
    "Email" : "Corrièl",
    "Mail %s" : "Mail %s",
    "Phone" : "Telefòn",
    "Call %s" : "Sonar %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Veire %s sus Twitter",
    "Website" : "Site web",
    "Visit %s" : "Visitar %s",
    "Address" : "Adreça",
    "Profile picture" : "Imatge de perfil",
    "About" : "A prepaus",
    "Headline" : "Títol",
    "Organisation" : "Organizacion",
    "Role" : "Ròtle",
    "Additional settings" : "Paramètres addicionals",
    "Set an admin password." : "Definir un senhal admin.",
    "Open »%s«" : "Dobrir « %s »",
    "Sunday" : "dimenge",
    "Monday" : "diluns",
    "Tuesday" : "dimars",
    "Wednesday" : "dimècres",
    "Thursday" : "dijòus",
    "Friday" : "divendres",
    "Saturday" : "dissabte",
    "January" : "Genièr",
    "February" : "Febrièr",
    "March" : "Març",
    "April" : "Abril",
    "May" : "Mai",
    "June" : "Junh",
    "July" : "Julhet",
    "August" : "Agost",
    "September" : "Setembre",
    "October" : "Octòbre",
    "November" : "Novembre",
    "December" : "Decembre",
    "May." : "Mai.",
    "a safe home for all your data" : "un ostal segur per vòstras donadas",
    "Authentication error" : "Error d’autentificacion",
    "Storage is temporarily not available" : "Emmagazinatge temporàriament indisponible",
    "Full name" : "Nom complèt",
    "User disabled" : "Utilizaire desactivat"
},
"nplurals=2; plural=(n > 1);");
